Modify libsensors scanner build flags...

* add -8
When using -Cf, flex defaults to generating a 7-bit scanner instead of 8-bit.
That's a bug, since we want the scanner to handle any character.  Using -8 restores
the proper behavior.

* change -Cf to -Cfe
This allows a nice reduction in object size (from ~60KiB to ~15KiB) with almost
no impact to speed (adds < 100 cycles to scanner, where total cycles is > 1M).



git-svn-id: http://lm-sensors.org/svn/lm-sensors/trunk@4272 7894878c-1315-0410-8ee3-d5d059ff63e0
This commit is contained in:
Mark M. Hoffman committed 2006-12-29 21:07:24 +00:00
1 parent c34c264f97
commit b5ff067425
1 file changed
+2 -2
+2 -2
View File
@@ -477,9 +477,9 @@ manhtml:
$(BISON) -p sensors_yy -d $< -o $@
ifeq ($(DEBUG),1)
FLEX_FLAGS := -Psensors_yy -t -b -Cf
FLEX_FLAGS := -Psensors_yy -t -b -Cfe -8
else
FLEX_FLAGS := -Psensors_yy -t -Cf
FLEX_FLAGS := -Psensors_yy -t -Cfe -8
endif
%.c: %.l